PROGRAM_NAME='TOSHIBA, JK-S44A, RELAY, BASIC, 12-94, BA'
(*   DATE:05/20/99    TIME:16:42:54    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(***********************************************************)
(* GENERAL FUNCTION LIST -                                 *)
(*   ALARM, FREEZE FRAME, QUAD IMAGE, STATUS,              *)
(*   SWITCHING (4 X 1)                                     *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

QUAD = 1                     (* AXC-REL14 *)
INPUTS = 2                   (* AXC-INP8 *)
PANEL  = 128

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(* RELAYS *)
IMAGE_1    = 1
IMAGE_2    = 2
IMAGE_3    = 3
IMAGE_4    = 4
IMAGE_QUAD = 5
AUTO_SW    = 6
SEQ_SW     = 7
FREEZE_1   = 8
FREEZE_2   = 9
FREEZE_3   = 10
FREEZE_4   = 11
CH_DISP    = 12

(* INPUTS *)
IN_SI_1 = 1
IN_SI_2 = 2
IN_QUAD = 3

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

IMAGE
AUTO_SWITCH
FREEZE[4]
CHAR_DISP

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

([QUAD,IMAGE_1],[QUAD,IMAGE_2],[QUAD,IMAGE_3],
 [QUAD,IMAGE_4],[QUAD,IMAGE_QUAD])

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)


(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

PUSH[PANEL,11]
PUSH[PANEL,12]
PUSH[PANEL,13]
PUSH[PANEL,14]
PUSH[PANEL,15]
{
  IMAGE = PUSH_CHANNEL - 10
  MIN_TO[QUAD,IMAGE]
  OFF[AUTO_SWITCH]
}
[PANEL,11] = (([INPUTS,IN_SI_1] AND [INPUTS,IN_SI_2]) AND NOT[INPUTS,IN_QUAD])
[PANEL,12] = (((NOT[INPUTS,IN_SI_1]) AND [INPUTS,IN_SI_2]) AND NOT([INPUTS,IN_QUAD]))
[PANEL,13] = (([INPUTS,IN_SI_1] AND NOT[INPUTS,IN_SI_2]) AND NOT[INPUTS,IN_QUAD])
[PANEL,14] = (((NOT[INPUTS,IN_SI_1]) AND NOT[INPUTS,IN_SI_2]) AND NOT[INPUTS,IN_QUAD])
[PANEL,15] = [INPUTS,IN_QUAD]

PUSH[PANEL,16]
{
  ON[AUTO_SWITCH]
  MIN_TO[QUAD,AUTO_SW]
}
[PANEL,16] = AUTO_SWITCH

PUSH[PANEL,17]
{
  MIN_TO[QUAD,SEQ_SW]
  OFF[AUTO_SWITCH]
}
[PANEL,17] = [QUAD,SEQ_SW]

PUSH[PANEL,18]
PUSH[PANEL,19]
PUSH[PANEL,20]
PUSH[PANEL,21]
{
  IMAGE = PUSH_CHANNEL - 10
  MIN_TO[QUAD,IMAGE]
  FREEZE[IMAGE-7] = NOT[FREEZE[IMAGE-7]]
}
[PANEL,18] = FREEZE[1]
[PANEL,19] = FREEZE[2]
[PANEL,20] = FREEZE[3]
[PANEL,21] = FREEZE[4]

PUSH[PANEL,22]
{
  CHAR_DISP = NOT(CHAR_DISP)
  MIN_TO[QUAD,CH_DISP]
}
[PANEL,22] = CHAR_DISP

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

